#!/bin/bash
# MotiveWave should be installed under the following directory
SCRIPTDIR=/usr/share/motivewave

# Classpath: dynamically load all jar files in the "jar" directory 
CP=""
for entry in "$SCRIPTDIR/jar/"*.jar
do
CP+=":$entry"
done
# trim the first ':'
CP=$(echo $CP| cut -c 2-)

# Maximum Heap.  By default this will be one quarter of the system memory. Optionally this can be hard coded (see below)
MAX_HEAP=""
# Maximum VRAM.  By default this will be 2048 MB. Optionally this can be hard coded (see below)
MAX_VRAM="2048M"
# Additional VM arguments
VM_ARGS=""

# Scaling does not seem to picked up automatically and defaults to 100% (at least on the desktops that we tested).
# Try to get the scale setting for the gnome desktop, but typically this seems to return 0...
gsettings get org.gnome.desktop.interface scaling-factor
SCALE=`gsettings get org.gnome.desktop.interface scaling-factor|awk '{print $2}'`

# If this is 0, then try to guess from the screen resolution
if [[ $SCALE == 0 || $SCALE == "" || !($SCALE =~ ^[0-9]*[.]?[0-9]*$) ]]; then
xrandr --query|grep -A 1 "connected primary"|grep -v connected
H=`xrandr --query|grep -A 1 "connected primary"|grep -v connected|awk '{print $1}'|awk -Fx '{print $2}'`
echo "Resolution: $H"
SCALE=1
if [[ $H -gt 1800 ]]; then SCALE=2; fi
if [[ $H -gt 4000 ]]; then SCALE=3; fi
fi

# Convert this to a percentage
SCALE=$(echo "$SCALE*100" | bc)
SCALE=${SCALE%.*}
SCALE+="%"

# Pull information from the .settings file in the motivewave directory
SETTINGS_FILE=~/.motivewave/startup.ini
if test -f "$SETTINGS_FILE"; then
  # Ignore comments '#'
  LINES=`grep -v '^#' $SETTINGS_FILE `
  IFS=$'\n'
  for LINE in $LINES
  do
    IFS='='
    read -r N V <<< "$LINE"
    V="${V##*( )}"
    if [[ $N = "MAX_HEAP" && $V != "" ]]; then MAX_HEAP="-Xmx$V"; fi
    if [[ $N = "MAX_VRAM" && $V != "" ]]; then MAX_VRAM="$V"; fi
    if [[ $N = "SCALE" && $V != "" ]]; then SCALE="$V"; fi
    if [[ $N = "VM_ARGS" ]]; then VM_ARGS="$V"; fi
  done
  if [[ $MAX_HEAP != "" || $VM_ARGS != "" ]]; then
    echo "Reading Startup Options from: $SETTINGS_FILE"
    echo "Max Heap: $MAX_HEAP"
    echo "Max VRAM: $MAX_VRAM"
    echo "VM Args: $VM_ARGS"
  fi
  IFS=''
fi

if [[ $MAX_VRAM == "" ]]; then MAX_VRAM="2048M"; fi

echo "Scaling: $SCALE"
echo "Max Heap: $MAX_HEAP"
echo "Max VRAM: $MAX_VRAM"
echo "VM Args: $VM_ARGS"

# Start the JVM.  For convenience java has been renamed to motivewave so that is easier to identify in the System Monitor
$SCRIPTDIR/jre/bin/motivewave $MAX_HEAP -Djdk.gtk.version=2 -Dprism.forceGPU=true -Dsun.java2d.opengl=true -Dprism.order=es2,es1,sw,j2d -Dsun.java2d.pmoffscreen=false -Dprism.vsync=false -Dprism.lcdtext=false -Dawt.useSystemAAFontSettings=false  $VM_ARGS -javaagent:"$SCRIPTDIR/jar/MotiveWave.jar" -Dname="MotiveWave"  -Djava.library.path="$SCRIPTDIR/lib" -DUserHome="$HOME" -Duser.dir="$HOME" -DappDir="$SCRIPTDIR" -DLibraryDirectory="$HOME/Library" -DDocumentsDirectory="$HOME/Documents" -DCachesDirectory="$HOME/Library/Caches" -DDesktopDirectory="$HOME/Desktop" -DDownloadsDirectory="$HOME/Downloads" -DSharedPublicDirectory="$HOME/Public" -Dprism.verbose=true -Dprism.maxvram=$MAX_VRAM -Dglass.gtk.uiScale=$SCALE -Dsun.java2d.uiScale=$SCALE -p "$SCRIPTDIR/javafx" --add-modules=javafx.controls,javafx.base,javafx.graphics,javafx.media,javafx.web,javafx.swing --add-exports javafx.web/com.sun.webkit.network=ALL-UNNAMED -classpath "$CP" MotiveWave

